<no title> — CALCEPH - Python language 3.4.1 documentation

The units of PV.
This integer is a sum of some unit constants (CALCEPH_UNIT_???) and/or the constant `USE_NAIFID`.
If the unit contains `USE_NAIFID`, the NAIF identification numbering system is used for the target (NAIF identification numbers for the list).
If the unit does not contain `USE_NAIFID`, the old number system is used for the target (see the list in the function `calcephpy.CalcephBin.compute()`).